==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/test/t_NumericalPoint_description.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_NumericalPoint_description.cxx
 *  @brief The test file of class NumericalPoint for standard methods
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: t_NumericalPoint_description.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include <iostream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "NumericalPointWithDescription.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Type;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  /* Constructor with size */
  NumericalPointWithDescription point1(2);
  point1[0] = 100.;
  point1[1] = 101.;

  /* Copy constructor */
  NumericalPointWithDescription point2(point1);


  {
    /* Description */
    fullprint << "point1.getDescription() = "
	      << point1.getDescription()
	      << std::endl;

    fullprint << "point2.getDescription() = "
	      << point2.getDescription()
	      << std::endl;
  }



  Description description(2);
  description[0] = "point1_X";
  description[1] = "point1_Y";

  point1.setDescription(description);


  {
    fullprint << "point1.getDescription() = "
	      << point1.getDescription()
	      << std::endl;

    fullprint << "point2.getDescription() = "
	      << point2.getDescription()
	      << std::endl;
  }



  return ExitCode::Success;
}

==> openturns_0.15.orig.tar.gz: openturns-0.15/lib/test/t_NumericalPoint_description.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_NumericalPoint_description.cxx
 *  @brief The test file of class NumericalPoint for standard methods
 *
 *  (C) Copyright 2005-2011 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: schueller $
 *  @date:   $LastChangedDate: 2011-07-28 18:31:43 +0200 (Thu, 28 Jul 2011) $
 *  Id:      $Id: t_NumericalPoint_description.cxx 2046 2011-07-28 16:31:43Z schueller $
 */
#include <iostream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "NumericalPointWithDescription.hxx"
#include "Collection.hxx"
#include "NumericalPoint.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Type;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  /* Constructor with size */
  NumericalPointWithDescription point1(2);
  point1[0] = 100.;
  point1[1] = 101.;

  /* Copy constructor */
  NumericalPointWithDescription point2(point1);


  {
    /* Description */
    fullprint << "point1.getDescription() = "
              << point1.getDescription()
              << std::endl;

    fullprint << "point2.getDescription() = "
              << point2.getDescription()
              << std::endl;
  }



  Description description(2);
  description[0] = "point1_X";
  description[1] = "point1_Y";

  point1.setDescription(description);


  {
    fullprint << "point1.getDescription() = "
              << point1.getDescription()
              << std::endl;

    fullprint << "point2.getDescription() = "
              << point2.getDescription()
              << std::endl;
  }

  // Creation
  Collection<NumericalPointWithDescription> coll1(5, NumericalPointWithDescription(4));
  Collection<NumericalPointWithDescription> coll2(5, NumericalPoint(4));
  Collection<NumericalPoint> coll3(5, NumericalPointWithDescription(4));
  Collection<NumericalPoint> coll4(5, NumericalPoint(4));
  // Conversion
  //coll1 = coll3;
  //coll4 = coll2;
  return ExitCode::Success;
}
